@@ -10,7 +10,7 @@ import deskbar.Match
 
 from deskbar.defs import VERSION
 from deskbar.Watcher import FileWatcher
-from deskbar.Utils import spawn_async
+from deskbar.Utils import spawn_async, url_show_file
 
 
 HANDLERS = {
@@ -35,8 +35,8 @@ class FileMatch(deskbar.Match.Match):
 		self.absname = absname
 				
 	def action(self, text=None):
-		gnome.url_show(self.absname)
-	
+		url_show_file(self.absname)
+
 	def is_valid(self, text=None):
 		return exists(self.absname)
 		
@@ -57,7 +57,7 @@ class FolderMatch(deskbar.Match.Match):
 		self.absname = absname
 		
 	def action(self, text=None):
-		gnome.url_show(self.absname)
+		url_show_file(self.absname)
 	
 	def is_valid(self, text=None):
 		return exists(self.absname)
